# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/processing/processing.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2
from yamcs.protobuf.pvalue import pvalue_pb2 as yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2 as yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/processing/processing.proto',
  package='yamcs.protobuf.processing',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\017ProcessingProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/processing/processing.proto\x12\x19yamcs.protobuf.processing\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/commanding/commanding.proto\x1a\"yamcs/protobuf/pvalue/pvalue.proto\x1a\x34yamcs/protobuf/yamcsManagement/yamcsManagement.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"+\n\x1aListProcessorTypesResponse\x12\r\n\x05types\x18\x01 \x03(\t\")\n\x15ListProcessorsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"[\n\x16ListProcessorsResponse\x12\x41\n\nprocessors\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\":\n\x13GetProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"=\n\x16\x44\x65leteProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"|\n\x16\x43reateProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x63lientId\x18\x03 \x03(\x05\x12\x12\n\npersistent\x18\x04 \x01(\x08\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x06 \x01(\t\"\x83\x01\n\x14\x45\x64itProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12(\n\x04seek\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05speed\x18\x05 \x01(\t\"q\n\x18GetParameterValueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tfromCache\x18\x04 \x01(\x08\x12\x0f\n\x07timeout\x18\x05 \x01(\x04\"s\n\x18SetParameterValueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12$\n\x05value\x18\x04 \x01(\x0b\x32\x15.yamcs.protobuf.Value\"\x94\x01\n\x1e\x42\x61tchGetParameterValuesRequest\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x11\n\tprocessor\x18\x05 \x01(\t\x12)\n\x02id\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x11\n\tfromCache\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x04\"W\n\x1f\x42\x61tchGetParameterValuesResponse\x12\x34\n\x05value\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\"\x97\x02\n\x1e\x42\x61tchSetParameterValuesRequest\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x11\n\tprocessor\x18\x03 \x01(\t\x12\x63\n\x07request\x18\x01 \x03(\x0b\x32R.yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest\x1ak\n\x18SetParameterValueRequest\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\"\xce\x02\n\x13IssueCommandRequest\x12\x10\n\x08instance\x18\x06 \x01(\t\x12\x11\n\tprocessor\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12M\n\nassignment\x18\x01 \x03(\x0b\x32\x39.yamcs.protobuf.processing.IssueCommandRequest.Assignment\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x03 \x01(\x05\x12\x0e\n\x06\x64ryRun\x18\x04 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12\x41\n\x0e\x63ommandOptions\x18\n \x01(\x0b\x32).yamcs.protobuf.commanding.CommandOptions\x1a)\n\nAssignment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xe1\x01\n\x14IssueCommandResponse\x12\n\n\x02id\x18\x05 \x01(\t\x12\x32\n\x0egenerationTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x08 \x01(\x05\x12\x13\n\x0b\x63ommandName\x18\t \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0b\n\x03hex\x18\x03 \x01(\t\x12\x0e\n\x06\x62inary\x18\x04 \x01(\x0c\x12\x10\n\x08username\x18\x0b \x01(\t\x12\r\n\x05queue\x18\n \x01(\t\"\xa4\x01\n\x1bUpdateCommandHistoryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x46\n\nattributes\x18\x05 \x03(\x0b\x32\x32.yamcs.protobuf.commanding.CommandHistoryAttribute2\xe3\x0f\n\rProcessingApi\x12\x7f\n\x12ListProcessorTypes\x12\x16.google.protobuf.Empty\x1a\x35.yamcs.protobuf.processing.ListProcessorTypesResponse\"\x1a\x8a\x92\x03\x16\n\x14/api/processor-types\x12\x8c\x01\n\x0eListProcessors\x12\x30.yamcs.protobuf.processing.ListProcessorsRequest\x1a\x31.yamcs.protobuf.processing.ListProcessorsResponse\"\x15\x8a\x92\x03\x11\n\x0f/api/processors\x12\x9b\x01\n\x0cGetProcessor\x12..yamcs.protobuf.processing.GetProcessorRequest\x1a-.yamcs.protobuf.yamcsManagement.ProcessorInfo\",\x8a\x92\x03(\n&/api/processors/{instance}/{processor}\x12\x8a\x01\n\x0f\x44\x65leteProcessor\x12\x31.yamcs.protobuf.processing.DeleteProcessorRequest\x1a\x16.google.protobuf.Empty\",\x8a\x92\x03(\"&/api/processors/{instance}/{processor}\x12\x89\x01\n\rEditProcessor\x12/.yamcs.protobuf.processing.EditProcessorRequest\x1a\x16.google.protobuf.Empty\"/\x8a\x92\x03+*&/api/processors/{instance}/{processor}:\x01*\x12v\n\x0f\x43reateProcessor\x12\x31.yamcs.protobuf.processing.CreateProcessorRequest\x1a\x16.google.protobuf.Empty\"\x18\x8a\x92\x03\x14\x1a\x0f/api/processors:\x01*\x12\xb0\x01\n\x11GetParameterValue\x12\x33.yamcs.protobuf.processing.GetParameterValueRequest\x1a%.yamcs.protobuf.pvalue.ParameterValue\"?\x8a\x92\x03;\n9/api/processors/{instance}/{processor}/parameters/{name*}\x12\xee\x01\n\x11SetParameterValue\x12\x33.yamcs.protobuf.processing.SetParameterValueRequest\x1a\x16.google.protobuf.Empty\"\x8b\x01\x8a\x92\x03\x86\x01\x12\x39/api/processors/{instance}/{processor}/parameters/{name*}:\x05valueZB\x1a\x39/api/processors/{instance}/{processor}/parameters/{name*}:\x05value\x12\xd5\x01\n\x17\x42\x61tchGetParameterValues\x12\x39.yamcs.protobuf.processing.BatchGetParameterValuesRequest\x1a:.yamcs.protobuf.processing.BatchGetParameterValuesResponse\"C\x8a\x92\x03?\x1a:/api/processors/{instance}/{processor}/parameters:batchGet:\x01*\x12\xb1\x01\n\x17\x42\x61tchSetParameterValues\x12\x39.yamcs.protobuf.processing.BatchSetParameterValuesRequest\x1a\x16.google.protobuf.Empty\"C\x8a\x92\x03?\x1a:/api/processors/{instance}/{processor}/parameters:batchSet:\x01*\x12\xb1\x01\n\x0cIssueCommand\x12..yamcs.protobuf.processing.IssueCommandRequest\x1a/.yamcs.protobuf.processing.IssueCommandResponse\"@\x8a\x92\x03<\x1a\x37/api/processors/{instance}/{processor}/commands/{name*}:\x01*\x12\xae\x01\n\x14UpdateCommandHistory\x12\x36.yamcs.protobuf.processing.UpdateCommandHistoryRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a=/api/processors/{instance}/{processor}/commandhistory/{name*}:\x01*B\'\n\x12org.yamcs.protobufB\x0fProcessingProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_LISTPROCESSORTYPESRESPONSE = _descriptor.Descriptor(
  name='ListProcessorTypesResponse',
  full_name='yamcs.protobuf.processing.ListProcessorTypesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='yamcs.protobuf.processing.ListProcessorTypesResponse.types', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=369,
)


_LISTPROCESSORSREQUEST = _descriptor.Descriptor(
  name='ListProcessorsRequest',
  full_name='yamcs.protobuf.processing.ListProcessorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.ListProcessorsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=412,
)


_LISTPROCESSORSRESPONSE = _descriptor.Descriptor(
  name='ListProcessorsResponse',
  full_name='yamcs.protobuf.processing.ListProcessorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processors', full_name='yamcs.protobuf.processing.ListProcessorsResponse.processors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=505,
)


_GETPROCESSORREQUEST = _descriptor.Descriptor(
  name='GetProcessorRequest',
  full_name='yamcs.protobuf.processing.GetProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetProcessorRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=507,
  serialized_end=565,
)


_DELETEPROCESSORREQUEST = _descriptor.Descriptor(
  name='DeleteProcessorRequest',
  full_name='yamcs.protobuf.processing.DeleteProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.DeleteProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.DeleteProcessorRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=628,
)


_CREATEPROCESSORREQUEST = _descriptor.Descriptor(
  name='CreateProcessorRequest',
  full_name='yamcs.protobuf.processing.CreateProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.CreateProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.CreateProcessorRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='yamcs.protobuf.processing.CreateProcessorRequest.clientId', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.processing.CreateProcessorRequest.persistent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.processing.CreateProcessorRequest.type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.processing.CreateProcessorRequest.config', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=630,
  serialized_end=754,
)


_EDITPROCESSORREQUEST = _descriptor.Descriptor(
  name='EditProcessorRequest',
  full_name='yamcs.protobuf.processing.EditProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.EditProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.EditProcessorRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.processing.EditProcessorRequest.state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seek', full_name='yamcs.protobuf.processing.EditProcessorRequest.seek', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='yamcs.protobuf.processing.EditProcessorRequest.speed', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=888,
)


_GETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='GetParameterValueRequest',
  full_name='yamcs.protobuf.processing.GetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetParameterValueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetParameterValueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.GetParameterValueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromCache', full_name='yamcs.protobuf.processing.GetParameterValueRequest.fromCache', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.processing.GetParameterValueRequest.timeout', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=1003,
)


_SETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='SetParameterValueRequest',
  full_name='yamcs.protobuf.processing.SetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.SetParameterValueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.SetParameterValueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.SetParameterValueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.SetParameterValueRequest.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1005,
  serialized_end=1120,
)


_BATCHGETPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='BatchGetParameterValuesRequest',
  full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.instance', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.processor', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.id', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromCache', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.fromCache', index=3,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.timeout', index=4,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1271,
)


_BATCHGETPARAMETERVALUESRESPONSE = _descriptor.Descriptor(
  name='BatchGetParameterValuesResponse',
  full_name='yamcs.protobuf.processing.BatchGetParameterValuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.BatchGetParameterValuesResponse.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1273,
  serialized_end=1360,
)


_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='SetParameterValueRequest',
  full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1535,
  serialized_end=1642,
)

_BATCHSETPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='BatchSetParameterValuesRequest',
  full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.instance', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.processor', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.request', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1363,
  serialized_end=1642,
)


_ISSUECOMMANDREQUEST_ASSIGNMENT = _descriptor.Descriptor(
  name='Assignment',
  full_name='yamcs.protobuf.processing.IssueCommandRequest.Assignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.IssueCommandRequest.Assignment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.IssueCommandRequest.Assignment.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1938,
  serialized_end=1979,
)

_ISSUECOMMANDREQUEST = _descriptor.Descriptor(
  name='IssueCommandRequest',
  full_name='yamcs.protobuf.processing.IssueCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.IssueCommandRequest.instance', index=0,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.IssueCommandRequest.processor', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.IssueCommandRequest.name', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignment', full_name='yamcs.protobuf.processing.IssueCommandRequest.assignment', index=3,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.processing.IssueCommandRequest.origin', index=4,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.processing.IssueCommandRequest.sequenceNumber', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='yamcs.protobuf.processing.IssueCommandRequest.dryRun', index=6,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.processing.IssueCommandRequest.comment', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandOptions', full_name='yamcs.protobuf.processing.IssueCommandRequest.commandOptions', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ISSUECOMMANDREQUEST_ASSIGNMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1645,
  serialized_end=1979,
)


_ISSUECOMMANDRESPONSE = _descriptor.Descriptor(
  name='IssueCommandResponse',
  full_name='yamcs.protobuf.processing.IssueCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.IssueCommandResponse.id', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.processing.IssueCommandResponse.generationTime', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.processing.IssueCommandResponse.origin', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.processing.IssueCommandResponse.sequenceNumber', index=3,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.processing.IssueCommandResponse.commandName', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.processing.IssueCommandResponse.source', index=5,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hex', full_name='yamcs.protobuf.processing.IssueCommandResponse.hex', index=6,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='yamcs.protobuf.processing.IssueCommandResponse.binary', index=7,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.processing.IssueCommandResponse.username', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.processing.IssueCommandResponse.queue', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1982,
  serialized_end=2207,
)


_UPDATECOMMANDHISTORYREQUEST = _descriptor.Descriptor(
  name='UpdateCommandHistoryRequest',
  full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='yamcs.protobuf.processing.UpdateCommandHistoryRequest.attributes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2210,
  serialized_end=2374,
)

_LISTPROCESSORSRESPONSE.fields_by_name['processors'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_EDITPROCESSORREQUEST.fields_by_name['seek'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SETPARAMETERVALUEREQUEST.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_BATCHGETPARAMETERVALUESREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHGETPARAMETERVALUESRESPONSE.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.containing_type = _BATCHSETPARAMETERVALUESREQUEST
_BATCHSETPARAMETERVALUESREQUEST.fields_by_name['request'].message_type = _BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST
_ISSUECOMMANDREQUEST_ASSIGNMENT.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST.fields_by_name['assignment'].message_type = _ISSUECOMMANDREQUEST_ASSIGNMENT
_ISSUECOMMANDREQUEST.fields_by_name['commandOptions'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDOPTIONS
_ISSUECOMMANDRESPONSE.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPDATECOMMANDHISTORYREQUEST.fields_by_name['attributes'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYATTRIBUTE
DESCRIPTOR.message_types_by_name['ListProcessorTypesResponse'] = _LISTPROCESSORTYPESRESPONSE
DESCRIPTOR.message_types_by_name['ListProcessorsRequest'] = _LISTPROCESSORSREQUEST
DESCRIPTOR.message_types_by_name['ListProcessorsResponse'] = _LISTPROCESSORSRESPONSE
DESCRIPTOR.message_types_by_name['GetProcessorRequest'] = _GETPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['DeleteProcessorRequest'] = _DELETEPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['CreateProcessorRequest'] = _CREATEPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['EditProcessorRequest'] = _EDITPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['GetParameterValueRequest'] = _GETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['SetParameterValueRequest'] = _SETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['BatchGetParameterValuesRequest'] = _BATCHGETPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['BatchGetParameterValuesResponse'] = _BATCHGETPARAMETERVALUESRESPONSE
DESCRIPTOR.message_types_by_name['BatchSetParameterValuesRequest'] = _BATCHSETPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandRequest'] = _ISSUECOMMANDREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandResponse'] = _ISSUECOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateCommandHistoryRequest'] = _UPDATECOMMANDHISTORYREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListProcessorTypesResponse = _reflection.GeneratedProtocolMessageType('ListProcessorTypesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORTYPESRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListProcessorTypesResponse)
  })
_sym_db.RegisterMessage(ListProcessorTypesResponse)

ListProcessorsRequest = _reflection.GeneratedProtocolMessageType('ListProcessorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORSREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListProcessorsRequest)
  })
_sym_db.RegisterMessage(ListProcessorsRequest)

ListProcessorsResponse = _reflection.GeneratedProtocolMessageType('ListProcessorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORSRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListProcessorsResponse)
  })
_sym_db.RegisterMessage(ListProcessorsResponse)

GetProcessorRequest = _reflection.GeneratedProtocolMessageType('GetProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetProcessorRequest)
  })
_sym_db.RegisterMessage(GetProcessorRequest)

DeleteProcessorRequest = _reflection.GeneratedProtocolMessageType('DeleteProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.DeleteProcessorRequest)
  })
_sym_db.RegisterMessage(DeleteProcessorRequest)

CreateProcessorRequest = _reflection.GeneratedProtocolMessageType('CreateProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.CreateProcessorRequest)
  })
_sym_db.RegisterMessage(CreateProcessorRequest)

EditProcessorRequest = _reflection.GeneratedProtocolMessageType('EditProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.EditProcessorRequest)
  })
_sym_db.RegisterMessage(EditProcessorRequest)

GetParameterValueRequest = _reflection.GeneratedProtocolMessageType('GetParameterValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETERVALUEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetParameterValueRequest)
  })
_sym_db.RegisterMessage(GetParameterValueRequest)

SetParameterValueRequest = _reflection.GeneratedProtocolMessageType('SetParameterValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPARAMETERVALUEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SetParameterValueRequest)
  })
_sym_db.RegisterMessage(SetParameterValueRequest)

BatchGetParameterValuesRequest = _reflection.GeneratedProtocolMessageType('BatchGetParameterValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchGetParameterValuesRequest)
  })
_sym_db.RegisterMessage(BatchGetParameterValuesRequest)

BatchGetParameterValuesResponse = _reflection.GeneratedProtocolMessageType('BatchGetParameterValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETPARAMETERVALUESRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchGetParameterValuesResponse)
  })
_sym_db.RegisterMessage(BatchGetParameterValuesResponse)

BatchSetParameterValuesRequest = _reflection.GeneratedProtocolMessageType('BatchSetParameterValuesRequest', (_message.Message,), {

  'SetParameterValueRequest' : _reflection.GeneratedProtocolMessageType('SetParameterValueRequest', (_message.Message,), {
    'DESCRIPTOR' : _BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest)
    })
  ,
  'DESCRIPTOR' : _BATCHSETPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchSetParameterValuesRequest)
  })
_sym_db.RegisterMessage(BatchSetParameterValuesRequest)
_sym_db.RegisterMessage(BatchSetParameterValuesRequest.SetParameterValueRequest)

IssueCommandRequest = _reflection.GeneratedProtocolMessageType('IssueCommandRequest', (_message.Message,), {

  'Assignment' : _reflection.GeneratedProtocolMessageType('Assignment', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDREQUEST_ASSIGNMENT,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.IssueCommandRequest.Assignment)
    })
  ,
  'DESCRIPTOR' : _ISSUECOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.IssueCommandRequest)
  })
_sym_db.RegisterMessage(IssueCommandRequest)
_sym_db.RegisterMessage(IssueCommandRequest.Assignment)

IssueCommandResponse = _reflection.GeneratedProtocolMessageType('IssueCommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISSUECOMMANDRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.IssueCommandResponse)
  })
_sym_db.RegisterMessage(IssueCommandResponse)

UpdateCommandHistoryRequest = _reflection.GeneratedProtocolMessageType('UpdateCommandHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMMANDHISTORYREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.UpdateCommandHistoryRequest)
  })
_sym_db.RegisterMessage(UpdateCommandHistoryRequest)


DESCRIPTOR._options = None

_PROCESSINGAPI = _descriptor.ServiceDescriptor(
  name='ProcessingApi',
  full_name='yamcs.protobuf.processing.ProcessingApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2377,
  serialized_end=4396,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListProcessorTypes',
    full_name='yamcs.protobuf.processing.ProcessingApi.ListProcessorTypes',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTPROCESSORTYPESRESPONSE,
    serialized_options=b'\212\222\003\026\n\024/api/processor-types',
  ),
  _descriptor.MethodDescriptor(
    name='ListProcessors',
    full_name='yamcs.protobuf.processing.ProcessingApi.ListProcessors',
    index=1,
    containing_service=None,
    input_type=_LISTPROCESSORSREQUEST,
    output_type=_LISTPROCESSORSRESPONSE,
    serialized_options=b'\212\222\003\021\n\017/api/processors',
  ),
  _descriptor.MethodDescriptor(
    name='GetProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.GetProcessor',
    index=2,
    containing_service=None,
    input_type=_GETPROCESSORREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO,
    serialized_options=b'\212\222\003(\n&/api/processors/{instance}/{processor}',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.DeleteProcessor',
    index=3,
    containing_service=None,
    input_type=_DELETEPROCESSORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003(\"&/api/processors/{instance}/{processor}',
  ),
  _descriptor.MethodDescriptor(
    name='EditProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.EditProcessor',
    index=4,
    containing_service=None,
    input_type=_EDITPROCESSORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003+*&/api/processors/{instance}/{processor}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='CreateProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.CreateProcessor',
    index=5,
    containing_service=None,
    input_type=_CREATEPROCESSORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003\024\032\017/api/processors:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='GetParameterValue',
    full_name='yamcs.protobuf.processing.ProcessingApi.GetParameterValue',
    index=6,
    containing_service=None,
    input_type=_GETPARAMETERVALUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE,
    serialized_options=b'\212\222\003;\n9/api/processors/{instance}/{processor}/parameters/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='SetParameterValue',
    full_name='yamcs.protobuf.processing.ProcessingApi.SetParameterValue',
    index=7,
    containing_service=None,
    input_type=_SETPARAMETERVALUEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003\206\001\0229/api/processors/{instance}/{processor}/parameters/{name*}:\005valueZB\0329/api/processors/{instance}/{processor}/parameters/{name*}:\005value',
  ),
  _descriptor.MethodDescriptor(
    name='BatchGetParameterValues',
    full_name='yamcs.protobuf.processing.ProcessingApi.BatchGetParameterValues',
    index=8,
    containing_service=None,
    input_type=_BATCHGETPARAMETERVALUESREQUEST,
    output_type=_BATCHGETPARAMETERVALUESRESPONSE,
    serialized_options=b'\212\222\003?\032:/api/processors/{instance}/{processor}/parameters:batchGet:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='BatchSetParameterValues',
    full_name='yamcs.protobuf.processing.ProcessingApi.BatchSetParameterValues',
    index=9,
    containing_service=None,
    input_type=_BATCHSETPARAMETERVALUESREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003?\032:/api/processors/{instance}/{processor}/parameters:batchSet:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='IssueCommand',
    full_name='yamcs.protobuf.processing.ProcessingApi.IssueCommand',
    index=10,
    containing_service=None,
    input_type=_ISSUECOMMANDREQUEST,
    output_type=_ISSUECOMMANDRESPONSE,
    serialized_options=b'\212\222\003<\0327/api/processors/{instance}/{processor}/commands/{name*}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCommandHistory',
    full_name='yamcs.protobuf.processing.ProcessingApi.UpdateCommandHistory',
    index=11,
    containing_service=None,
    input_type=_UPDATECOMMANDHISTORYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003B\032=/api/processors/{instance}/{processor}/commandhistory/{name*}:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSINGAPI)

DESCRIPTOR.services_by_name['ProcessingApi'] = _PROCESSINGAPI

# @@protoc_insertion_point(module_scope)
