# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/commanding/queue_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/commanding/queue_service.proto',
  package='yamcs.protobuf.commanding',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\021QueueServiceProtoP\001',
  serialized_pb=b'\n-yamcs/protobuf/commanding/queue_service.proto\x12\x19yamcs.protobuf.commanding\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/commanding/commanding.proto\"8\n\x11ListQueuesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"Q\n\x12ListQueuesResponse\x12;\n\x06queues\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.commanding.CommandQueueInfo\"D\n\x0fGetQueueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"T\n\x10\x45\x64itQueueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\"L\n\x17ListQueueEntriesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"Y\n\x18ListQueueEntriesResponse\x12=\n\x07\x65ntries\x18\x01 \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\"g\n\x15\x45\x64itQueueEntryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04uuid\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t2\xe5\x06\n\x08QueueApi\x12\x9e\x01\n\nListQueues\x12,.yamcs.protobuf.commanding.ListQueuesRequest\x1a-.yamcs.protobuf.commanding.ListQueuesResponse\"3\x8a\x92\x03/\n-/api/processors/{instance}/{processor}/queues\x12\x9f\x01\n\x08GetQueue\x12*.yamcs.protobuf.commanding.GetQueueRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\":\x8a\x92\x03\x36\n4/api/processors/{instance}/{processor}/queues/{name}\x12\xa6\x01\n\x0bUpdateQueue\x12+.yamcs.protobuf.commanding.EditQueueRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\"=\x8a\x92\x03\x39*4/api/processors/{instance}/{processor}/queues/{name}:\x01*\x12\xbf\x01\n\x10ListQueueEntries\x12\x32.yamcs.protobuf.commanding.ListQueueEntriesRequest\x1a\x33.yamcs.protobuf.commanding.ListQueueEntriesResponse\"B\x8a\x92\x03>\n</api/processors/{instance}/{processor}/queues/{name}/entries\x12\xaa\x01\n\x10UpdateQueueEntry\x12\x30.yamcs.protobuf.commanding.EditQueueEntryRequest\x1a\x16.google.protobuf.Empty\"L\x8a\x92\x03H*C/api/processors/{instance}/{processor}/queues/{name}/entries/{uuid}:\x01*B)\n\x12org.yamcs.protobufB\x11QueueServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,])




_LISTQUEUESREQUEST = _descriptor.Descriptor(
  name='ListQueuesRequest',
  full_name='yamcs.protobuf.commanding.ListQueuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ListQueuesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.ListQueuesRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=234,
)


_LISTQUEUESRESPONSE = _descriptor.Descriptor(
  name='ListQueuesResponse',
  full_name='yamcs.protobuf.commanding.ListQueuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queues', full_name='yamcs.protobuf.commanding.ListQueuesResponse.queues', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=317,
)


_GETQUEUEREQUEST = _descriptor.Descriptor(
  name='GetQueueRequest',
  full_name='yamcs.protobuf.commanding.GetQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.GetQueueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.GetQueueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.GetQueueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=387,
)


_EDITQUEUEREQUEST = _descriptor.Descriptor(
  name='EditQueueRequest',
  full_name='yamcs.protobuf.commanding.EditQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.EditQueueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.EditQueueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.EditQueueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.commanding.EditQueueRequest.state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=473,
)


_LISTQUEUEENTRIESREQUEST = _descriptor.Descriptor(
  name='ListQueueEntriesRequest',
  full_name='yamcs.protobuf.commanding.ListQueueEntriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ListQueueEntriesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.ListQueueEntriesRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.ListQueueEntriesRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=551,
)


_LISTQUEUEENTRIESRESPONSE = _descriptor.Descriptor(
  name='ListQueueEntriesResponse',
  full_name='yamcs.protobuf.commanding.ListQueueEntriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='yamcs.protobuf.commanding.ListQueueEntriesResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=642,
)


_EDITQUEUEENTRYREQUEST = _descriptor.Descriptor(
  name='EditQueueEntryRequest',
  full_name='yamcs.protobuf.commanding.EditQueueEntryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.state', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=644,
  serialized_end=747,
)

_LISTQUEUESRESPONSE.fields_by_name['queues'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO
_LISTQUEUEENTRIESRESPONSE.fields_by_name['entries'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEENTRY
DESCRIPTOR.message_types_by_name['ListQueuesRequest'] = _LISTQUEUESREQUEST
DESCRIPTOR.message_types_by_name['ListQueuesResponse'] = _LISTQUEUESRESPONSE
DESCRIPTOR.message_types_by_name['GetQueueRequest'] = _GETQUEUEREQUEST
DESCRIPTOR.message_types_by_name['EditQueueRequest'] = _EDITQUEUEREQUEST
DESCRIPTOR.message_types_by_name['ListQueueEntriesRequest'] = _LISTQUEUEENTRIESREQUEST
DESCRIPTOR.message_types_by_name['ListQueueEntriesResponse'] = _LISTQUEUEENTRIESRESPONSE
DESCRIPTOR.message_types_by_name['EditQueueEntryRequest'] = _EDITQUEUEENTRYREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListQueuesRequest = _reflection.GeneratedProtocolMessageType('ListQueuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUESREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueuesRequest)
  })
_sym_db.RegisterMessage(ListQueuesRequest)

ListQueuesResponse = _reflection.GeneratedProtocolMessageType('ListQueuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUESRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueuesResponse)
  })
_sym_db.RegisterMessage(ListQueuesResponse)

GetQueueRequest = _reflection.GeneratedProtocolMessageType('GetQueueRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUEUEREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.GetQueueRequest)
  })
_sym_db.RegisterMessage(GetQueueRequest)

EditQueueRequest = _reflection.GeneratedProtocolMessageType('EditQueueRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITQUEUEREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.EditQueueRequest)
  })
_sym_db.RegisterMessage(EditQueueRequest)

ListQueueEntriesRequest = _reflection.GeneratedProtocolMessageType('ListQueueEntriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUEENTRIESREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueueEntriesRequest)
  })
_sym_db.RegisterMessage(ListQueueEntriesRequest)

ListQueueEntriesResponse = _reflection.GeneratedProtocolMessageType('ListQueueEntriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUEENTRIESRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueueEntriesResponse)
  })
_sym_db.RegisterMessage(ListQueueEntriesResponse)

EditQueueEntryRequest = _reflection.GeneratedProtocolMessageType('EditQueueEntryRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITQUEUEENTRYREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.EditQueueEntryRequest)
  })
_sym_db.RegisterMessage(EditQueueEntryRequest)


DESCRIPTOR._options = None

_QUEUEAPI = _descriptor.ServiceDescriptor(
  name='QueueApi',
  full_name='yamcs.protobuf.commanding.QueueApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=750,
  serialized_end=1619,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListQueues',
    full_name='yamcs.protobuf.commanding.QueueApi.ListQueues',
    index=0,
    containing_service=None,
    input_type=_LISTQUEUESREQUEST,
    output_type=_LISTQUEUESRESPONSE,
    serialized_options=b'\212\222\003/\n-/api/processors/{instance}/{processor}/queues',
  ),
  _descriptor.MethodDescriptor(
    name='GetQueue',
    full_name='yamcs.protobuf.commanding.QueueApi.GetQueue',
    index=1,
    containing_service=None,
    input_type=_GETQUEUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=b'\212\222\0036\n4/api/processors/{instance}/{processor}/queues/{name}',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateQueue',
    full_name='yamcs.protobuf.commanding.QueueApi.UpdateQueue',
    index=2,
    containing_service=None,
    input_type=_EDITQUEUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=b'\212\222\0039*4/api/processors/{instance}/{processor}/queues/{name}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ListQueueEntries',
    full_name='yamcs.protobuf.commanding.QueueApi.ListQueueEntries',
    index=3,
    containing_service=None,
    input_type=_LISTQUEUEENTRIESREQUEST,
    output_type=_LISTQUEUEENTRIESRESPONSE,
    serialized_options=b'\212\222\003>\n</api/processors/{instance}/{processor}/queues/{name}/entries',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateQueueEntry',
    full_name='yamcs.protobuf.commanding.QueueApi.UpdateQueueEntry',
    index=4,
    containing_service=None,
    input_type=_EDITQUEUEENTRYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003H*C/api/processors/{instance}/{processor}/queues/{name}/entries/{uuid}:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_QUEUEAPI)

DESCRIPTOR.services_by_name['QueueApi'] = _QUEUEAPI

# @@protoc_insertion_point(module_scope)
